function P = projectionMatrix( f, c, R, t )
%PROJECTIONMATRIX this function calculates the projection matrix
%   the inputs are
%       f 2x1 focal length [fx; fy]
%       c 2x1 image center [cx; cy]
%       R 3x3 rotation matrix
%       t 3x1 -RC, where C is the position of the projection center.
%   the output is a 3x4 matrix which converts the homogeneous coordinates 
%   of the points in the world frame to the homogeneous image coordinates.

assert(isequal(size(f), [2,1]));
assert(isequal(size(c), [2,1]));
assert(isequal(size(R), [3,3]));
assert(isequal(size(t), [3,1]));

fx = f(1); fy = f(2);
cx = c(1); cy = c(2);

K = [fx, 0, cx;
    0, fy, cy;
    0, 0, 1];

P = K * [R, t];

end

