function epi_line = rectifiedEpipolarLine( px, img_size, D_range)
%RECTIFIEDEPIPOLARLINE calculates the epipolar line for the rectified case
%	
%   inputs:
%       px 2x1 input pixel on one image [col, row]
%       img_size 2x1 image size [cols, rows]
%       D_range 2x1 search disparity range
%   outputs:
%       epi_line 2xn all pixel coordinates [col, row] on the epipolar line

assert(isequal(size(px), [2,1]));
assert(isequal(size(img_size), [2,1]));
assert(isequal(size(D_range), [2,1]));
assert(D_range(2) >= D_range(1));

% for rectified case, the epipolar line should have the same row
% coordinate as px
low_bound = 1;
if px(1)+D_range(1) > 1 && px(1)+D_range(1) < img_size(1)
    low_bound = px(1)+D_range(1);
end
upper_bound = img_size(1);
if px(1)+D_range(2) < upper_bound && px(1)+D_range(2) > 1
    upper_bound = px(1)+D_range(2);
end

epi_line = zeros(2, upper_bound-low_bound+1);
for i=low_bound:upper_bound
    epi_line(:, i-low_bound+1) = [i; px(2)];
end

end

