%% this script calculate the dense disparity map from a pair of stereo images
clear;
close all;
clc;
addpath('./plot');

%% specify dataset and parameters
dataset = 'playroom_s'; img_format = 'png';
img0 = strcat(dataset, '0.', img_format);
img1 = strcat(dataset, '1.', img_format);

load(strcat(dataset, '_calib'));

half_win_size = 6;
win_size = 2 * half_win_size + 1;

%% load and display
I0 = imread(img0); I0 = rgb2gray(I0);
I1 = imread(img1); I1 = rgb2gray(I1);
I0_pad = padarray(I0, [half_win_size, half_win_size], 'replicate');
I1_pad = padarray(I1, [half_win_size, half_win_size], 'replicate');

%% calcualte dense disparity map
disparity = zeros(img_size(2), img_size(1));

for i = 1:img_size(1)
    disp(strcat('processing column: ', num2str(i)));
    for j = 1:img_size(2)
        px0 = [i;j];
        [match_idx, epi1, ~] = searchEpipolar(I0_pad, I1_pad, px0, half_win_size, D_range, {'SAD'});
        px1 = epi1(:, match_idx(1));
        disparity(j,i) = norm(px1 - px0);
    end
end

%% computer the depth map
depth = f1(1) * baseline * (disparity.^(-1)); 


%% display
figure('Name', 'disparity map', 'NumberTitle', 'off');
imshow(disparity, fliplr(abs(D_range')));
figure('Name', 'depth map', 'NumberTitle', 'off');
mesh(flipud(depth));
view([0,0,3]);

