function pt = triangulatePoint( x1, x2, P1, P2 )
%TRIANGULATEPOINT linear triangulation
%   Input:
%       x1 x2: 2x1 images points in camera1 and camera2 respectively
%       P1 P2: 3x4 projection matrix of camera1 and camera2 respectively
%   Output:
%       pt: 3x1 triangulated 3D points
assert(isequal(size(x1), [2,1]));
assert(isequal(size(x2), [2,1]));
assert(isequal(size(P1), [3,4]));
assert(isequal(size(P2), [3,4]));

% ==> DELETE
x1 = [x1;1];
x2 = [x2;1];
x1_skew = [0, -x1(3), x1(2); x1(3), 0, -x1(1); -x1(2), x1(1), 0];
x2_skew = [0, -x2(3), x2(2); x2(3), 0, -x2(1); -x2(2), x2(1), 0];

A = [x1_skew*P1; x2_skew*P2];
% <== DELETE

[~,~,v] = svd(A,0);
pt_homo = v(:,4);
pt_homo = pt_homo / pt_homo(4);
pt = pt_homo(1:3);

end

